package com.sun.tools.javap.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "21.0.9+10" },
            { "jdk", "21.0.9" },
            { "release", "21.0.9" },
        };
    }
}
